pub enum ParseError {
ParseIntError(ParseIntError),
InvalidLength(usize),
}Expand description
An error which can be returned when parsing color from an RGB hexadecimal string.
See Color for specifications for the string.
Variants
ParseIntError(ParseIntError)
The string could not be parsed to valid integers.
InvalidLength(usize)
The string is of invalid length.